

#ifndef _BLOOM_H
#define _BLOOM_H

#include <stddef.h>
#include <stdint.h>
#include <stdbool.h>

/* 
   Based on 
   https://git.sr.ht/~sircmpwn/bloom/tree/master/LICENSE 
*/

struct bloom_filter {
  uint8_t *bits;
  size_t size;
};

#define NEXT_DEDUP_BLOOM_RESET 60 /* 1 min */

/* Creates a new bloom filter with no hash functions and size * 8 bits. */
struct bloom_filter* bloom_create(size_t size);

/* Frees a bloom filter. */
void bloom_free(struct bloom_filter*  filter);

/* Resets a bloom */
void bloom_reset(struct bloom_filter*  filter);

void bloom_add(struct bloom_filter*  filter, u_int32_t hash);

/* Tests if an item is in the bloom filter.
 *
 * Returns false if the item has definitely not been added before. Returns true
 * if the item was probably added before. */
bool bloom_test(struct bloom_filter*  filter, u_int32_t hash);

#endif
